@@ -16,9 +16,9 @@ c ==============================================================================
 C
 *     OUTPUT
 *
-*     IFLBVP = 0   SUCCESFULL TERMINATION
+*     IFLBVP = 0   SUCCESSFULL TERMINATION
 *
-*     IFLBVP = -1 (SUCCESSFULL TERMINATION BUT CONDITIONING PARAMETER
+*     IFLBVP = -1 (SUCCESSFULL TERMINATION BUT CONDITIONING PARAMETERS
 *                    NOT STABILIZED (ONLY IF USE_C = .true.)
 *
 *     IFLBVP = 1   terminated too many mesh points
@@ -670,7 +670,7 @@ c
            CALL Rprintd1('stiffness = ', sigma)
            CALL Rprintd1('gamma1    = ', gamma1)
            CALL Rprintd1('kappa1    = ', ckappa1)
-           CALL Rprintd1('kappa     = ', ckappa)           
+           CALL Rprintd1('kappa     = ', ckappa)
            CALL Rprintd1('kappa2    = ', ckappa2)
           end if
 
@@ -692,11 +692,11 @@ c karline: added ill_con_newt
         ill_cond_newt = ckappa2 .ge.  1d10 .and. ckappa2 .lt. flmax
 
            if (iprint .eq. 1) then
-             CALL Rprintd1('stab_kappa = ', stab_kappa)
-             CALL Rprintd1('stab_kappa1 = ', stab_kappa1)
-             CALL Rprintd1('stab_gamma = ', stab_gamma)
-             CALL Rprintd1('stiff_cond = ', stiff_cond)
-             CALL Rprinti1('ill_cond   = ', ill_cond)
+             CALL Rprintl1('stab_kappa = ', stab_kappa)
+             CALL Rprintl1('stab_kappa1 = ', stab_kappa1)
+             CALL Rprintl1('stab_gamma = ', stab_gamma)
+             CALL Rprintl1('stiff_cond = ', stiff_cond)
+             CALL Rprintl1('ill_cond   = ', ill_cond)
            end if
            if (ill_cond .and. use_c) goto 2000
 
@@ -732,7 +732,7 @@ c endif if (comp_c)
            CALL Rprintd1('stiffness = ', sigma)
            CALL Rprintd1('gamma1    = ', gamma1)
            CALL Rprintd1('kappa1    = ', ckappa1)
-           CALL Rprintd1('kappa     = ', ckappa)           
+           CALL Rprintd1('kappa     = ', ckappa)
            CALL Rprintd1('kappa2    = ', ckappa2)
           end if
 
@@ -752,12 +752,12 @@ c endif if (comp_c)
 
          if (ill_cond .and. use_c) goto 2000
          if (iprint .eq. 1) then
-             CALL Rprintd1('stab_sigma = ',stab_sigma)
-             CALL Rprintd1('stab_kappa = ', stab_kappa)
-             CALL Rprintd1('stab_kappa1 = ', stab_kappa1)
-             CALL Rprintd1('stab_gamma = ', stab_gamma)
-             CALL Rprintd1('stiff_cond = ', stiff_cond)
-             CALL Rprinti1('ill_cond   = ', ill_cond)
+             CALL Rprintl1('stab_sigma = ',stab_sigma)
+             CALL Rprintl1('stab_kappa = ', stab_kappa)
+             CALL Rprintl1('stab_kappa1 = ', stab_kappa1)
+             CALL Rprintl1('stab_gamma = ', stab_gamma)
+             CALL Rprintl1('stiff_cond = ', stiff_cond)
+             CALL Rprintl1('ill_cond   = ', ill_cond)
          end if
          end if
        end if
