@@ -17,7 +17,7 @@ c ==============================================================================
 *
 *     IFLBVP = 0   SUCCESFULL TERMINATION
 *
-*     IFLBVP = -1 (SUCCESSFULL TERMINATION BUT CONDITIONING PARAMETER
+*     IFLBVP = -1 (SUCCESFULL TERMINATION BUT CONDITIONING PARAMETERS
 *                    NOT STABILIZED (ONLY IF USE_C = .true.)
 *
 *     IFLBVP = 1   terminated too many mesh points
@@ -688,7 +688,7 @@ c       BY BRUGNANO & TRIGIANTE, AND HIGHAM
             CALL Rprintd1('stiffness = ', sigma)
             CALL Rprintd1('gamma1    = ', gamma1)
             CALL Rprintd1('kappa1    = ', ckappa1)
-            CALL Rprintd1('kappa     = ', ckappa)           
+            CALL Rprintd1('kappa     = ', ckappa)
             CALL Rprintd1('kappa2    = ', ckappa2)
            end if
 
@@ -717,12 +717,12 @@ c          stab_cond = stab_kappa1 .and. stab_gamma
           if (ill_cond .and. use_c) goto 2000
 
            if (iprint .eq. 1) then
-             CALL Rprintd1('stab_sigma = ',stab_sigma)
-             CALL Rprintd1('stab_kappa = ', stab_kappa)
-             CALL Rprintd1('stab_kappa1 = ', stab_kappa1)
-             CALL Rprintd1('stab_gamma = ', stab_gamma)
-             CALL Rprintd1('stiff_cond = ', stiff_cond)
-             CALL Rprinti1('ill_cond   = ', ill_cond)
+             CALL Rprintl1('stab_sigma = ',stab_sigma)
+             CALL Rprintl1('stab_kappa = ', stab_kappa)
+             CALL Rprintl1('stab_kappa1 = ', stab_kappa1)
+             CALL Rprintl1('stab_gamma = ', stab_gamma)
+             CALL Rprintl1('stiff_cond = ', stiff_cond)
+             CALL Rprintl1('ill_cond   = ', ill_cond)
            end if
         end if
 c endif if (comp_c)
@@ -758,7 +758,7 @@ c
             CALL Rprintd1('stiffness = ', sigma)
             CALL Rprintd1('gamma1    = ', gamma1)
             CALL Rprintd1('kappa1    = ', ckappa1)
-            CALL Rprintd1('kappa     = ', ckappa)           
+            CALL Rprintd1('kappa     = ', ckappa)
             CALL Rprintd1('kappa2    = ', ckappa2)
            end if
 
@@ -786,12 +786,12 @@ c         stab_cond = stab_kappa1 .and. stab_gamma
 
 
            if (iprint .eq. 1) then
-             CALL Rprintd1('stab_sigma = ',stab_sigma)
-             CALL Rprintd1('stab_kappa = ', stab_kappa)
-             CALL Rprintd1('stab_kappa1 = ', stab_kappa1)
-             CALL Rprintd1('stab_gamma = ', stab_gamma)
-             CALL Rprintd1('stiff_cond = ', stiff_cond)
-             CALL Rprinti1('ill_cond   = ', ill_cond)
+             CALL Rprintl1('stab_sigma = ',stab_sigma)
+             CALL Rprintl1('stab_kappa = ', stab_kappa)
+             CALL Rprintl1('stab_kappa1 = ', stab_kappa1)
+             CALL Rprintl1('stab_gamma = ', stab_gamma)
+             CALL Rprintl1('stiff_cond = ', stiff_cond)
+             CALL Rprintl1('ill_cond   = ', ill_cond)
            end if
         end if
        end if
